====================
Python ClimaCell API
====================


.. image:: https://img.shields.io/pypi/v/pyclimacell.svg
        :target: https://pypi.python.org/pypi/pyclimacell

.. image:: https://img.shields.io/travis/raman325/pyclimacell.svg
        :target: https://travis-ci.com/raman325/pyclimacell

.. image:: https://readthedocs.org/projects/pyclimacell/badge/?version=latest
        :target: https://pyclimacell.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Async Python3.7+ package to access the `CliamCell Weather API<https://www.climacell.co/weather-api/>`


* Free software: MIT license
* Documentation: https://pyclimacell.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
